==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/SciFigs/src/GridProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef GRIDPROPERTIES_H
#define GRIDPROPERTIES_H

#include <QGpGuiTools.h>
#include <QGpCoreMath.h>

#include "ui_GridProperties.h"

namespace SciFigs {

class GridPlot;

class GridProperties : public PropertyWidget, protected Ui::GridProperties
{
  Q_OBJECT
public:
  GridProperties(QWidget * parent=nullptr);

  enum Properties {ShowGrid, Smooth, FillValue, FillValueInversed, FillType};

  static Rect::Area item2area(int index);
  static int area2item(Rect::Area ft);
};

} // namespace SciFigs

#endif // GRIDPROPERTIES_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/SciFigs/src/GridProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef GRIDPROPERTIES_H
#define GRIDPROPERTIES_H

#include <QGpGuiTools.h>
#include <QGpCoreMath.h>

#include "ui_GridProperties.h"

namespace SciFigs {

class GridPlot;

class GridProperties : public PropertyWidget, protected Ui::GridProperties
{
  Q_OBJECT
public:
  GridProperties(QWidget * parent=nullptr);

  enum Properties {ShowGrid, Smooth, FillValue, FillValueInverse, FillType};

  static Rect::Area item2area(int index);
  static int area2item(Rect::Area ft);
};

} // namespace SciFigs

#endif // GRIDPROPERTIES_H
